searchNodes=[{"doc":"Defines a connection to a Cayley instance. Graph Definition To start connecting to a Cayley instance you need to define a connection module: defmodule MyGraph do use Caylir.Graph, otp_app: :my_application end If you intend to use initializer modules this module then needs to be inserted into the supervision tree of your application: children = [ # ... MyGraph, # ... ] Graph Configuration Referring back to the previously mentioned module: defmodule MyGraph do use Caylir.Graph, otp_app: :my_application end This connection will fetch it&#39;s configuration from the application environment as defined by :otp_app: config :my_application, MyGraph, host: &quot;cayley.example.com&quot; As an alternative you can define the configuration in the module definition itself: defmodule MyGraph do use Caylir.Graph, config: [ host: &quot;cayley.example.com&quot; ] Both inline and :otp_app configuration can be mixed. In this case the application configuration will overwrite any inline values. For more information on how (and what) to configure your connection please refer to the documentation of Caylir.Graph.Config. Graph Usage Querying Data By default a query is sent to the Gizmo language endpoint: MyGraph.query(&quot;graph.Vertex(&#39;graph&#39;).Out(&#39;connection&#39;).All()&quot;) If you want to send a query to a language specific endpoint not configured as your default (e.g. if you are mixing Gizmo and GraphQL queries) you can pass the :language option: MyGraph.query(query, language: :gizmo) MyGraph.query(query, language: :graphql) If you want to limit the number of results you can pass the :limit option: MyGraph.query(query, limit: 3) MyGraph.query(query, limit: -1) Passing -1 will return &quot;unlimited&quot; results while also deactivating any potential default limits implied by Cayley itself. By default a query has a timeout of 5 seconds (5000ms). If you want to change that layout to a lower or higher value you can pass the :timeout option: MyGraph.query(query, timeout: 250) Writing Data You can write a single quad: MyGraph.write(%{ subject: &quot;graph&quot;, predicate: &quot;connection&quot;, object: &quot;target&quot; }) Or multiple quads at once: MyGraph.write([quad_1, quad_2]) Deleting Data You can delete a single quad: MyGraph.delete(%{ subject: &quot;graph&quot;, predicate: &quot;connection&quot;, object: &quot;target&quot; }) Or multiple quads at once: MyGraph.delete([quad_1, quad_2])","ref":"Caylir.Graph.html","title":"Caylir.Graph","type":"behaviour"},{"doc":"Returns a supervisable graph child_spec.","ref":"Caylir.Graph.html#c:child_spec/1","title":"Caylir.Graph.child_spec/1","type":"callback"},{"doc":"Returns the graph configuration.","ref":"Caylir.Graph.html#c:config/0","title":"Caylir.Graph.config/0","type":"callback"},{"doc":"Deletes a quad from the graph.","ref":"Caylir.Graph.html#c:delete/2","title":"Caylir.Graph.delete/2","type":"callback"},{"doc":"Queries the graph.","ref":"Caylir.Graph.html#c:query/2","title":"Caylir.Graph.query/2","type":"callback"},{"doc":"Gets the shape of a query.","ref":"Caylir.Graph.html#c:shape/2","title":"Caylir.Graph.shape/2","type":"callback"},{"doc":"Writes a quad to the graph.","ref":"Caylir.Graph.html#c:write/2","title":"Caylir.Graph.write/2","type":"callback"},{"doc":"","ref":"Caylir.Graph.html#t:t_delete/0","title":"Caylir.Graph.t_delete/0","type":"type"},{"doc":"","ref":"Caylir.Graph.html#t:t_quad/0","title":"Caylir.Graph.t_quad/0","type":"type"},{"doc":"","ref":"Caylir.Graph.html#t:t_query/0","title":"Caylir.Graph.t_query/0","type":"type"},{"doc":"","ref":"Caylir.Graph.html#t:t_write/0","title":"Caylir.Graph.t_write/0","type":"type"},{"doc":"How To Configure Configuration values can be stored in two locations: hardcoded inline application environment If you combine inline configuration with an :otp_app setting the inline defaults will be overwritten by and/or merged with the application environment values when the configuration is accessed. Additionally you can insert use your application supervision tree to trigger an initializer module (&quot;dynamic configuration&quot;) that is able to configure your application environment during startup. Inline Configuration For some use cases (e.g. testing) it may be sufficient to define hardcoded configuration defaults outside of your application environment: defmodule MyGraph do use Caylir.Graph, config: [ host: &quot;localhost&quot;, port: 64210 ] end Environment Configuration When not using hardcoded configuration values you can use the application environment for configuration: defmodule MyGraph do use Caylir.Graph, otp_app: :my_app end config :my_app, MyGraph, host: &quot;localhost&quot;, port: 64210 Dynamic Configuration If you cannot, or do not want to, use a static application config you can configure an initializer module that will be called every time your graph is started (or restarted) in your supervision tree: # {mod, fun} [ init: {MyInitModule, :my_init_mf} ] # {mod, fun, args} [ init: {MyInitModule, :my_init_mfargs, [:foo, :bar]} ] # the configured initializer module defmodule MyInitModule do @spec my_init_mf(module) :: :ok def my_init_mf(graph), do: my_init_mfargs(graph, :foo, :bar) @spec my_init_mfargs(module, atom, atom) :: :ok def my_init_mfargs(graph, :foo, :bar) do config = Keyword.merge( graph.config(), host: &quot;localhost&quot;, port: 64210 ) Application.put_env(:my_app, graph, config) end end When the graph is started the function will be called with the graph module as the first parameter with optional {m, f, args} parameters from your configuration following. This will be done before the graph is available for use. The initializer function is expected to always return :ok. What To Configure As every configuration value can be set both inline and using the application environment the documentation using plain keyword lists. Several configuration entries will be set to default values if they are not set manually: [ host: &quot;localhost&quot;, json_decoder: {Jason, :decode!, [[keys: :atoms]]}, json_encoder: {Jason, :encode!, []}, language: :gizmo, port: 64210, scheme: &quot;http&quot; ] Query Language Configuration By default all queries are expected to use the Gizmo query language. Using the configuration key :language you can switch the default language endpoint to use: [ language: :graphql ] The HTTP URLs used to send the queries (for both :query and :shape calls) are constructed as /api/v1/\#{call}/\#{language}. Depending on your choice and used Cayley version the :shape endpoint might not be available. Query Limit Configuration You can define a default query limit by adding it to your graph config: [ limit: -1 ] Query Timeout Configuration Using all default values and no specific parameters each query is allowed to take up to 5000 milliseconds (GenServer.call/2 timeout) to complete. That may be too long or not long enough in some cases. To change that timeout you can configure your graph: # lowering timeout to 500 ms [ query_timeout: 500 ] or pass an individual timeout for a single query: MyGraph.query(query, timeout: 250) A passed or graph wide timeout configuration override any :recv_timeout of your :hackney (HTTP client) configuration. This does not apply to write requests. They are currently only affected by configured :recv_timeout values. Setting a graph timeout enables you to have a different timeout for read and write requests. JSON Decoder/Encoder Configuration By default the library used for encoding/decoding JSON is :jason. For the time :caylir directly depends on it to ensure it is available. If you want to use another library you can switch it: [ json_decoder: MyJSONLibrary, json_encoder: MyJSONLibrary ] [ json_decoder: {MyJSONLibrary, :decoder_argless}, json_encoder: {MyJSONLibrary, :encoder_argless} ] [ json_decoder: {MyJSONLibrary, :decode_it, [[keys: :atoms]]}, json_encoder: {MyJSONLibrary, :encode_it, []} ] If you configure only a module name it will be called as module.decode!(binary) and module.encode!(map). When using a more complete {m, f} or {m, f, args} configuration the data to decode/encode will passed as the first argument with your configured extra arguments following.","ref":"Caylir.Graph.Config.html","title":"Caylir.Graph.Config","type":"module"},{"doc":"Retrieves the graph configuration for graph in otp_app.","ref":"Caylir.Graph.Config.html#config/3","title":"Caylir.Graph.Config.config/3","type":"function"}]